avetrteff2: Compute the average subpopulation treatment effect and the standardized average subpopulation treatment effect when two biomarkers are involved
Description
Compute the average subpopulation treatment effect and the standardized average subpopulation treatment effect when two biomarkers are involved
a list of three numbers: delta is the average subpopulation treatment effect, lambda is the standardized average subpopulation treatment effect, and cVar is the variance with respect to the truncated distribution with specified cutoff values
Arguments
z1z2
a numeric vector of two numbers that are standardized biomarker values
kappa
a number of the correlation coefficient between two biomarkers
rhovec
a numeric vector of two correlation coefficients between the output and two biomarkers
sigma
a number of the standard deviation of outcome
muminusmu0
a number of the difference between the mean of outcome and the minimal clinically important treatment effect
Author
Jiangtao Gou
References
Zhang, F. and Gou, J. (2025). Using multiple biomarkers for patient enrichment in two-stage clinical designs. Technical Report.