Find the difference between the average subpopulation treatment effect and the desired one
targetDel(z2, kkk, muminusmu0, kappa, rhovec, sigma, cDel)the difference between the average subpopulation treatment effect and the desired one
the standardized biomarker value of the second biomarker
the researchers' weighting preference between the two biomarkers
a number of the difference between the mean of outcome and the minimal clinically important treatment effect
a number of the correlation coefficient between two biomarkers
a numeric vector of two correlation coefficients between the output and two biomarkers
a number of the standard deviation of outcome
the desired average subpopulation treatment effect